==> nextcloud-18.0.4.tgz: nextcloud/apps/twofactor_backupcodes/l10n/tr.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "İki aşamalı kimlik doğrulama için yedek kodlarınızı oluşturdunuz",
    "Second-factor backup codes" : "İki aşamalı kimlik doğrulama yedek kodları",
    "Generate backup codes" : "Yedek kodları oluştur",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "İki aşamalı kimlik doğrulamayı etkinleştirdiniz ancak henüz yedek kodlarını üretmediniz. Bu kodlar herhangi bir nedenle ikinci aşamayı kullanamadığınızda hesabınıza erişebilmenizi sağlar.",
    "Backup code" : "Yedek kod",
    "Use backup code" : "Yedek kodu kullan",
    "Two factor backup codes" : "İki aşamalı kimlik doğrulama yedek kodları",
    "A two-factor auth backup codes provider" : "İki aşamalı kimlik doğrulaması için yedek kodlar sağlayıcısı",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Yedek kodları oluşturuldu.  {used} / {total} kod kullanılıyor.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Yedek kodlarınızı burada görebilirsiniz. Kodları daha sonra göremeyeceğiniz için bu kodları kaydedin ya da yazdırın",
    "Save backup codes" : "Yedek kodları kaydet",
    "Print backup codes" : "Yedek kodları yazdır",
    "Regenerate backup codes" : "Yedek kodlarını yeniden oluştur",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Yedek kodlarını yeniden oluşturursanız, eski kodlar geçersiz olur.",
    "An error occurred while generating your backup codes" : "Yedek kodlar oluşturulurken bir sorun çıktı",
    "{name} backup codes" : "{name} yedek kodları",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "İki aşamalı kimlik doğrulamasını ayarlarken yedek kodlarından birini kullanın.",
    "Submit" : "Gönder",
    "_" : "_",
    "_icon-loading-small_::_generate-backup-codes_" : ["simge-yukleniyor-kucuk","yedek-kodlari-olustur"],
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "İki aşamalı kimlik doğrulamasını etkinleştirmiş ancak yedek kodlarını üretmemişsiniz. İkinci aşamaya erişemediğiniz zaman kullanabilmek için yedek kodlarını üretmeyi unutmayın.",
    "function" : "işlev"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-19.0.4.tgz: nextcloud/apps/twofactor_backupcodes/l10n/tr.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "İki aşamalı kimlik doğrulama için yedek kodlarınızı oluşturdunuz",
    "Second-factor backup codes" : "İki aşamalı kimlik doğrulama yedek kodları",
    "Generate backup codes" : "Yedek kodları oluştur",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "İki aşamalı kimlik doğrulamayı etkinleştirdiniz ancak henüz yedek kodlarını üretmediniz. Bu kodlar herhangi bir nedenle ikinci aşamayı kullanamadığınızda hesabınıza erişebilmenizi sağlar.",
    "Backup code" : "Yedek kod",
    "Use backup code" : "Yedek kodu kullan",
    "Two factor backup codes" : "İki aşamalı kimlik doğrulama yedek kodları",
    "A two-factor auth backup codes provider" : "İki aşamalı kimlik doğrulaması için yedek kodlar sağlayıcısı",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Yedek kodları oluşturuldu.  {used} / {total} kod kullanılıyor.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Yedek kodlarınızı burada görebilirsiniz. Kodları daha sonra göremeyeceğiniz için bu kodları kaydedin ya da yazdırın",
    "Save backup codes" : "Yedek kodları kaydet",
    "Print backup codes" : "Yedek kodları yazdır",
    "Regenerate backup codes" : "Yedek kodlarını yeniden oluştur",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Yedek kodlarını yeniden oluşturursanız, eski kodlar geçersiz olur.",
    "An error occurred while generating your backup codes" : "Yedek kodlar oluşturulurken bir sorun çıktı",
    "{name} backup codes" : "{name} yedek kodları",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "İki aşamalı kimlik doğrulamasını ayarlarken yedek kodlarından birini kullanın.",
    "Submit" : "Gönder",
    "function" : "işlev",
    "_" : "_",
    "_icon-loading-small_::_generate-backup-codes_" : ["simge-yukleniyor-kucuk","yedek-kodlari-olustur"]
},
"nplurals=2; plural=(n > 1);");
